pub struct BusMessage {
pub element_id: Option<ElementId>,
pub event: BusEvent,
}Expand description
One bus event together with the stable graph identity of the element
that posted it. Drivers and standalone elements that do not belong to a
PipelineGraph use None.
Fields
element_id: Option<ElementId>event: BusEventTrait Implementations